@@ -4,7 +4,7 @@ import improviser.Progressions.Blues as Blues
 class Block:
 
 
-	progression = Blues.jazzy_blues
+	progression = Blues.standard_blues
 	
 	bpm = 200
 	iterations = 8
