@@ -4,18 +4,6 @@ from Blocks import Block
 from mingus.extra import fluidsynth
 from os import sys
 
-
-class Improviser:
-
-	options = {}
-
-	def __init__(self):
-		self.seq = Sequencer(Block())
-
-	def play(self):
-		self.seq.play()
-
-
 if __name__ == '__main__':
 
 	if not fluidsynth.init_fluidsynth():
