@@ -47,6 +47,10 @@ class Instrument:
 				self.last_chan = self.params["channel"]
 				self.playing = n
 				self.last_played = n
+				if state["paint_function"] != None:
+					for note in n:
+						state["paint_function"](note, self.params["channel"])
+
 
 	def generate_note(self, state):
 		return None
