@@ -15,6 +15,9 @@ class Sequencer:
 	play_iterations = 32
 	swing = True
 	wild = 0.4
+	paint_function = None
+	refresh_function = None
+	update_function = None
 
 	def __init__(self, song):
 		self.block = song
@@ -55,6 +58,9 @@ class Sequencer:
 		while i < len(self.chords) * ticks:
 			chord = self.chords[ i / ticks ]
 
+			if self.refresh_function != None:
+				self.refresh_function()
+
 			if chord != self.state["chord"]:
 				print chords.determine(chord)[0]
 				self.state["scale"] = diatonic.get_notes(self.key)
@@ -67,7 +73,10 @@ class Sequencer:
 			self.state["ticks"] = ticks
 			self.state["iteration_tick"] = i
 			self.state["wild"] = self.wild
+			self.state["paint_function"] = self.paint_function
 				
+			if self.update_function != None:
+				self.update_function()
 			self.play_instruments()
 			if not self.swing:
 				sleep(self.tick_length)
